[Bug c++/118069] g++ hangs during constraint subsumption
cvs-commit at gcc dot gnu.org
gcc-bugzilla@gcc.gnu.org
Thu Dec 19 17:01:49 GMT 2024
https://gcc.gnu.org/bugzilla/show_bug.cgi?id=118069
--- Comment #7 from GCC Commits <cvs-commit at gcc dot gnu.org> ---
The master branch has been updated by Patrick Palka <ppalka@gcc.gnu.org>:
https://gcc.gnu.org/g:7eac34a6c793540606a50e20c4c56bd98476d3a1
commit r15-6375-g7eac34a6c793540606a50e20c4c56bd98476d3a1
Author: Patrick Palka <ppalka@redhat.com>
Date: Thu Dec 19 12:00:31 2024 -0500
c++: optimize constraint subsumption [PR118069]
Since atomic constraints are interned the subsumption machinery can
safely use pointer instead of structural hashing for them. This speeds
up compilation of the testcase in the PR from ~3s to ~2s.
PR c++/118069
gcc/cp/ChangeLog:
* constraint.cc (atom_hasher): Define here, instead of ...
* cp-tree.h (atom_hasher): ... here.
* logic.cc (clause::m_set): Use pointer instead of structural
hashing.
Reviewed-by: Jason Merrill <jason@redhat.com>
More information about the Gcc-bugs
mailing list